import {Dialog, InfiniteScroll, List, PullToRefresh, SwipeAction} from 'antd-mobile'
import React, {Fragment, useContext, useEffect, useRef, useState} from 'react'
import {deleteTaskById, getTaskList, updateTaskStateById} from "../../utils";
import "./index.css"
import {useLocation, useNavigate, useOutletContext} from "react-router-dom";
import dayjs from "dayjs";
import {DATE_TIME_FORMAT, DATE_TIME_FORMAT_SIMPLE} from "../../utils/timeFormatUtil";
import {getDictionary} from "../../utils/dictUtil";
import {List as VirtualizedList,AutoSizer} from "react-virtualized";
import {MyRootContext} from "../../components/MyRootContext";

const reorder = (
    list,
    startIndex,
    endIndex
) => {
    const result = Array.from(list)
    const [removed] = result.splice(startIndex, 1)
    result.splice(endIndex, 0, removed)

    return result
}

const ToDoList = () => {
    const [taskList, setTaskList] = useState([])
    const [hasMore, setHasMore] = useState(true)
    const [pageNumber, setPageNumber] = useState(1)
    const [priorityMap, setPriorityMap] = useState([]);
    const [stateMap, setStateMap] = useState([])
    const navigate = useNavigate();
    let loading = false;
    const { state } = useContext(MyRootContext);
    const search = state.search
    console.log("从全局取出的search：" ,{search})
    const loadMore = async () => {
        console.log("loading:",pageNumber,loading)
        if (loading) {
            return
        }
        loading = true;
        console.log("loadMore", loading)
        const taskRes = await getTaskList({...search, "pageNumber": pageNumber});
        console.log({taskRes})
        setTaskList( [...taskList, ...taskRes.content])

        if (taskRes.page.number < taskRes.page.totalPages){
            setHasMore(true)
            setPageNumber(pageNumber + 1)
        }else {
            setHasMore(false)
            setPageNumber(1)
        }
        loading = false;
    }
    /**
     * 根据查询条件筛选本地列表，不触发接口
     */
    const localRefresh = () =>{

    }

    useEffect(() => {
        getDictionary("2").then(res => {
            setStateMap(res)
        })
        getDictionary("1").then(res => {
            setPriorityMap(res)
        })
        // getTaskList({...search, "pageNumber": pageNumber}).then(result => {
        //     setTaskList(result.content)
        //     if (result.page.number < result.page.totalPages){
        //         setHasMore(true)
        //         setPageNumber(pageNumber + 1)
        //     }else {
        //         setHasMore(false)
        //         setPageNumber(1)
        //     }
        //     loading = false;
        // })

    }, [useOutletContext()])
    const ref = useRef(null)
    return (
        <Fragment>
            {/* 下拉刷新 */}
            <PullToRefresh
                onRefresh={() => {
                    console.log("refresh")
                    loading = true;
                    getTaskList({...search, "pageNumber": 1}).then(result => {
                        setTaskList(result.content)
                        if (result.page.number < result.page.totalPages){
                            setHasMore(true)
                            setPageNumber(pageNumber + 1)
                        }else {
                            setHasMore(false)
                            setPageNumber(1)
                        }
                    })
                    loading= false;
                }}
            >
                <List>
                    {/*<AutoSizer disableHeight>*/}
                    {/*        <VirtualizedList*/}
                    {/*            rowCount={rowCount}*/}
                    {/*            rowRenderer={rowRenderer}*/}
                    {/*            width={width}*/}
                    {/*            height={480}*/}
                    {/*            rowHeight={60}*/}
                    {/*            overscanRowCount={10}*/}
                    {/*        />*/}
                    {/*</AutoSizer>*/}
                    {taskList.map((item, index) => (
                        <SwipeAction
                            ref={ref}
                            closeOnAction={false}
                            closeOnTouchOutside={false}
                            rightActions={[
                                {
                                    key: `delete${item.id}`,
                                    text: '删除',
                                    color: 'danger',
                                    onClick: () => {
                                        Dialog.confirm({
                                            content: '确定要删除吗？',
                                            onConfirm: () => {
                                                deleteTaskById(item.id).then(() => {
                                                    ref.current?.close()
                                                })
                                            },
                                            onClose: () => {
                                                console.log(ref)
                                                ref.current?.close()
                                            }
                                        })
                                    },
                                },
                                {
                                    key: `close${item.id}`,
                                    text: '关闭',
                                    color: 'warning',
                                    onClick: () => {
                                        Dialog.confirm({
                                            content: '确定要关闭吗？',
                                            onConfirm: () => {
                                                updateTaskStateById('6', item.id).then(res => {
                                                    ref.current?.close()
                                                })
                                            },
                                        })
                                    },
                                },
                                {
                                    key: `update${item.id}`,
                                    text: '修改',
                                    color: 'primary',
                                    onClick: () => {
                                        ref.current?.close()
                                        // 跳转
                                        navigate(`/detail/updateTask?id=${item.id}`)
                                    },
                                },
                                {
                                    key: `complete${item.id}`,
                                    text: '完成',
                                    color: 'success',
                                    onClick: () => {
                                        Dialog.confirm({
                                            content: '确定要完成吗？',
                                            onConfirm: () => {
                                                updateTaskStateById('7', item.id).then(res => {
                                                    ref.current?.close()
                                                    console.log({ref})
                                                })
                                            },
                                        })

                                    },
                                },
                            ]}
                        >
                            <List.Item
                                key={item.id}
                                // prefix={
                                //     <Image
                                //         src={item.avatar}
                                //         style={{ borderRadius: 20 }}
                                //         fit='cover'
                                //         width={40}
                                //         height={40}
                                //     />
                                // }
                                // title={<span style={{color: "red"}}>{item.name}</span>}
                                // children={item.description}
                                // description={item.state}
                                onClick={
                                    () => {
                                        console.log("click/detail")
                                        navigate(`/detail/selectTask?id=${item.id}`)
                                    }
                                }
                                title={
                                    <div style={{
                                        display: "flex",
                                        justifyContent: "space-between",
                                        alignItems: "center",
                                        flexDirection: "row",
                                        flexWrap: "nowrap",
                                        fontSize: "large",
                                        color: "black"
                                    }}>
                                        {(priorityMap.get(item.priority)?.jsonValue?.color) ?
                                            (<span
                                                style={{color: priorityMap.get(item.priority)?.jsonValue?.color}}>{item.name}</span>) : (
                                                <span>{item.name}</span>)}

                                        {item.expectedStartTime && (stateMap.get(item.state)?.jsonValue?.color ?
                                            (<span style={{color: stateMap.get(item.state)?.jsonValue?.color}}>
                                                 {dayjs(item.expectedStartTime).format(DATE_TIME_FORMAT_SIMPLE)}</span>) :
                                            (
                                                <span>{dayjs(item.expectedStartTime).format(DATE_TIME_FORMAT_SIMPLE)}</span>))
                                        }
                                    </div>}
                                description={item.description}
                            >
                            </List.Item>
                        </SwipeAction>
                    ))}
                </List>
                {/*无限滚动*/}
                <InfiniteScroll loadMore={loadMore} hasMore={hasMore}/>
            </PullToRefresh>
        </Fragment>
    )
}
export default ToDoList;